@@ -125,13 +125,9 @@ class MultipleValueRangeProcessor(xapian.ValueRangeProcessor):
 
 
 class Record(object):
-    """Default dumb record type, names begining with _xodb_ are reserved ."""
+    """Default dumb record type."""
 
-    def __init__(self, document, otype, newargs, state):
-        # this does not mangle the names
-        state.update(__xodb_document=document,
-                     __xodb_type=otype,
-                     __xodb_newargs=newargs)
+    def __init__(self, otype, newargs, state):
         self.__dict__ = state
 
 
@@ -140,7 +136,7 @@ class BrokenRecord(Record):
     pass
 
 
-def instance_factory(document, otype, newargs, state):
+def instance_factory(otype, newargs, state):
     inst = otype.__new__(otype, *newargs)
     inst.__dict__ = state
     return inst
@@ -176,10 +172,11 @@ class Database(object):
     value_prefix = "_XODB_VALUE_"
     value_sort_prefix = "_XODB_VALUESORT_"
     value_count_name = "_XODB_COUNT_"
+    weak_doc_map = None
 
     def __init__(self, db_or_path,
                  writable=True, overwrite=False,
-                 spelling=True, record_factory=Record,
+                 spelling=True, record_factory=Record, weak_doc_map=True,
                  persistent_id=None, persistent_load=None):
         self._writable = writable
         self.backend = db_or_path
@@ -241,23 +238,21 @@ class Database(object):
             data = compress(data)
         return data
 
-    def unserialize(self, document, record_factory=None):
-        
-        data = _decompress(document.get_data())
+    def unserialize(self, data, record_factory=None):
+        data = _decompress(data)
         file = StringIO(data)
         unpickler = Unpickler(file)
         try:
             otype, newargs = unpickler.load()
         except AttributeError:
-            # the type may have gone away ...
-            otype, newargs = BrokenRecord, ()
+            otype, newargs = Record, ()
         if self.persistent_load is not None:
             unpickler.persistent_load = self.persistent_load
         state = unpickler.load()
         if record_factory:
-            return record_factory(document, otype, newargs, state)
+            return record_factory(otype, newargs, state)
         else:
-            return document, otype, newargs, state
+            return otype, newargs, state
 
     def _get_value_count(self):
         return int(self.backend.get_metadata(self.value_count_name))
@@ -306,8 +301,8 @@ class Database(object):
             return default
 
     def __getitem__(self, docid):
-        document = self.backend.get_document(docid)
-        return self.unserialize(document, self.record_factory)
+        return self.unserialize(self.backend.get_document(docid).get_data(),
+                                self.record_factory)
 
     def __delitem__(self, docid):
         self.backend.delete_document(docid)
@@ -617,7 +612,8 @@ class Database(object):
             if document:
                 yield doc
             else:
-                obj = self.unserialize(doc, record_factory=self.record_factory)
+                obj = self.unserialize(doc.get_data(),
+                                       record_factory=self.record_factory)
                 yield obj
 
     def term_counter(self, prefixes):
